@@ -38,7 +38,12 @@ def data_preprocessing(path_expr, path_net, log2=True, zscores=True, size=2000,
             d_ppi = formats[1]
 
     expr = open_file(path_expr, d_expr)
+    g_id = list(expr[expr.columns[0]].values)
+    g_id = [str(x) for x in g_id]
+    p_id = [str(x) for x in expr.columns]
     expr = expr.set_index(expr.columns[0])
+    assert len(set(g_id).intersection(p_id)) == 0, "Patients and genes IDs must be unique, intersections betwen patient and gene IDs are not supported"
+
     patients_new = list(set(expr.columns))
     tot_pats = len(patients_new)
 
