@@ -39,6 +39,8 @@ class results_analysis():
             solution[0][0] = list(set(solution[0][0]).difference(isec))
             solution[0][1] = list(set(solution[0][1]).difference(isec))
             self.isec = list(isec)
+            self.isec_entr = [str(self.labels[x]) for x in self.isec]
+
         else:
             self.isec = []
         self.genes1 = [str(self.labels[x]) for x in self.solution[0][0]]
@@ -49,6 +51,8 @@ class results_analysis():
         if convert == True:
             assert origID != None, "Please specify the original gene ID or set 'convert' to False"
             all_genes = self.genes1 + self.genes2
+            if len(self.isec)>0:
+                all_genes = all_genes + self.isec_entr
             mg = mygene.MyGeneInfo()
             # set delay - if querying more than 1k genes it can get super slow
             mg.delay = 0.1
@@ -110,15 +114,14 @@ class results_analysis():
         all_genes_entr = self.genes1 + self.genes2
         all_genes = self.solution[0][0] + self.solution[0][1]
         if len(self.isec)>0:
-            isec_entr = [str(self.labels[x]) for x in self.isec]
-            all_genes_entr = all_genes_entr + isec_entr
+            all_genes_entr = all_genes_entr + self.isec_entr
             all_genes = all_genes + self.isec
 
         if self.convert:
             genes1_name = [self.mapping[x] for x in self.genes1]
             genes2_name = [self.mapping[x] for x in self.genes2]
             if len(self.isec) > 0:
-                isec_name = [self.mapping[x] for x in isec_entr]
+                isec_name = [self.mapping[x] for x in self.isec_entr]
                 all_genes_names = genes1_name + genes2_name + isec_name
             else:
 
@@ -146,7 +149,7 @@ class results_analysis():
             nl1 = self.genes1
             nl2 = self.genes2
             if len(self.isec) >0:
-                isec = isec_entr
+                isec = self.isec_entr
 
         means1 = list(np.mean(GE_small[self.patients1].loc[nl1], axis=1) - np.mean(
             GE_small[self.patients2].loc[nl1], axis=1).values)
@@ -210,9 +213,8 @@ class results_analysis():
             genes1_name = [self.mapping[x] for x in self.genes1]
             genes2_name = [self.mapping[x] for x in self.genes2]
             if len(self.isec) > 0:
-                isec_entr = [str(self.labels[x]) for x in self.isec]
 
-                isec_name = [self.mapping[x] for x in isec_entr]
+                isec_name = [self.mapping[x] for x in self.isec_entr]
                 all_genes_names = genes1_name + genes2_name + isec_name
             else:
 
@@ -221,8 +223,7 @@ class results_analysis():
             genes1_name = self.genes1
             genes2_name = self.genes2
             if len(self.isec) > 0:
-                isec_entr = [str(self.labels[x]) for x in self.isec]
-                all_genes_names = genes1_name + genes2_name + isec_entr
+                all_genes_names = genes1_name + genes2_name + self.isec_entr
             else:
 
                 all_genes_names = genes1_name + genes2_name
